<?php
/**
 * Asterisk Lite Theme Customizer
 *
 * @package Asterisk Lite
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function asterisk_lite_customize_register( $wp_customize ) {
	
	require get_template_directory().'/inc/customizer/active-callback.php';
	require get_template_directory().'/inc/customizer/custom-classes.php';
	require get_template_directory().'/inc/customizer/sanitize.php';
	require get_template_directory().'/inc/customizer/header.php';
	require get_template_directory().'/inc/customizer/typography.php';
	require get_template_directory().'/inc/customizer/social-icon.php';
	require get_template_directory().'/inc/customizer/social-share.php';
	require get_template_directory().'/inc/customizer/banner.php';
	require get_template_directory().'/inc/customizer/featured-stories.php';
	require get_template_directory().'/inc/customizer/cat-section.php';
	require get_template_directory().'/inc/customizer/related-post.php';
	require get_template_directory().'/inc/customizer/sidebar.php';
	require get_template_directory().'/inc/customizer/archive.php';
	require get_template_directory().'/inc/customizer/pagination.php';
	require get_template_directory().'/inc/customizer/single.php';
	require get_template_directory().'/inc/customizer/newsletter.php';
	require get_template_directory().'/inc/customizer/404.php';
	require get_template_directory().'/inc/customizer/footer.php';
	require get_template_directory().'/inc/customizer/home.php';
	
	$wp_customize->register_control_type( 'Asterisk_Lite_Sortable_Control' );
	
	$wp_customize->get_section( 'colors' )->panel = 'asterisk_lite_colors_panel';
	$wp_customize->get_section( 'colors' )->title = esc_html__('Color Options','asterisk-lite');
	$wp_customize->get_section( 'title_tagline' )->panel = 'asterisk_lite_general_settings';
	$wp_customize->get_section( 'header_image' )->panel = 'asterisk_lite_general_settings';
	$wp_customize->get_section( 'background_image' )->panel = 'asterisk_lite_general_settings';
	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';

	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial(
			'blogname',
			array(
				'selector'        => '.site-title a',
				'render_callback' => 'asterisk_lite_customize_partial_blogname',
			)
		);
		$wp_customize->selective_refresh->add_partial(
			'blogdescription',
			array(
				'selector'        => '.site-description',
				'render_callback' => 'asterisk_lite_customize_partial_blogdescription',
			)
		);
	}

    $wp_customize->add_panel( 'asterisk_lite_home',
        array(
            'title'      => esc_html__( 'Homepage Sections', 'asterisk-lite' ),
            'priority'   => 150,
            'capability' => 'edit_theme_options',
        )
    );

	$wp_customize->add_panel( 'asterisk_lite_options',
		array(
			'title'      => esc_html__( 'Theme Options', 'asterisk-lite' ),
			'priority'   => 150,
			'capability' => 'edit_theme_options',
		)
	);


	$wp_customize->add_panel( 'asterisk_lite_general_settings',
		array(
			'title'      => esc_html__( 'General Settings', 'asterisk-lite' ),
			'priority'   => 10,
			'capability' => 'edit_theme_options',
		)
	);

	$wp_customize->add_panel( 'asterisk_lite_colors_panel',
		array(
			'title'      => esc_html__( 'Color Settings', 'asterisk-lite' ),
			'priority'   => 15,
			'capability' => 'edit_theme_options',
		)
	);

	// Register custom section types.
	$wp_customize->register_section_type( 'Asterisk_Lite_Customize_Section_Upsell' );

	// Register sections.
	$wp_customize->add_section(
		new Asterisk_Lite_Customize_Section_Upsell(
			$wp_customize,
			'theme_upsell',
			array(
				'title'    => esc_html__( 'Asterisk Lite', 'asterisk-lite' ),
				'pro_text' => esc_html__( 'Upgrade To Pro', 'asterisk-lite' ),
				'pro_url'  => esc_url('https://wedevstudios.com/theme/asterisk-pro/'),
				'priority'  => 1,
			)
		)
	);


	$wp_customize->add_setting(
	    'asterisk_lite_premium_notiece',
	    array(
	        'default'           => '',
	        'capability'        => 'edit_theme_options',
	        'sanitize_callback' => 'sanitize_text_field'
	    )
	);
	$wp_customize->add_control(
	    new Asterisk_Lite_Premium_Notiece_Control( 
	        $wp_customize,
	        'asterisk_lite_premium_notiece',
	        array(
	            'label'      => esc_html__( 'Notice', 'asterisk-lite' ),
	            'settings' => 'asterisk_lite_premium_notiece',
	            'section'       => 'colors',
	        )
	    )
	);

}
add_action( 'customize_register', 'asterisk_lite_customize_register' );

/**
 * Render the site title for the selective refresh partial.
 *
 * @return void
 */
function asterisk_lite_customize_partial_blogname() {
	bloginfo( 'name' );
}

/**
 * Render the site tagline for the selective refresh partial.
 *
 * @return void
 */
function asterisk_lite_customize_partial_blogdescription() {
	bloginfo( 'description' );
}

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function asterisk_lite_customize_preview_js() {
	wp_enqueue_script( 'asterisk-lite-customizer-preview', get_template_directory_uri() . '/assets/js/customizer-preview.js', array( 'customize-preview' ), _S_VERSION, true );
}
add_action( 'customize_preview_init', 'asterisk_lite_customize_preview_js' );


if (!function_exists('asterisk_lite_customizer_scripts')) :

    function asterisk_lite_customizer_scripts(){

    	wp_enqueue_style( 'sifter', get_template_directory_uri() . '/assets/lib/sifter/sifter.min.css' );
    	wp_enqueue_style('asterisk-lite-customizer', get_template_directory_uri() . '/assets/css/customizer.css');

    	wp_enqueue_script('sifter', get_template_directory_uri() . '/assets/lib/sifter/sifter.min.js', array('jquery'), '', 1);
    	wp_enqueue_script('asterisk-lite-customizer', get_template_directory_uri() . '/assets/js/customizer.js', array('jquery','customize-controls', 'jquery-ui-core', 'jquery-ui-sortable'), '', 1);

    	wp_localize_script( 
	        'asterisk-lite-customizer',
	        'asterisk_lite_customizer',
	        array(
	            'ajax_url'   => esc_url( admin_url( 'admin-ajax.php' ) ),
	         )
	    );
    	
    }

endif;

add_action('customize_controls_enqueue_scripts', 'asterisk_lite_customizer_scripts');
add_action('customize_controls_init', 'asterisk_lite_customizer_scripts');